# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-09-12 08:07
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ldapauthbackend', '0002_ldapuserprofile_import_staff'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ldapuserprofile',
            name='import_staff',
            field=models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL),
        ),
    ]
