# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.apps import AppConfig


class LDAPAuthBackendConfig(AppConfig):
	name = 'ldapauthbackend'
	verbose_name = 'LDAP Authentication Backend'
