# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-09-19 06:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ldapauthbackend', '0003_auto_20180912_0807'),
    ]

    operations = [
        migrations.AddField(
            model_name='ldapuserprofile',
            name='account_name',
            field=models.CharField(default='', max_length=127),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='ldapuserprofile',
            name='account_uid',
            field=models.BigIntegerField(default=-1),
        ),
    ]
